﻿using System;
using System.Collections.Generic;
using System.Text;
using SNSHelper.Kaixin001.Entity;
using SNSHelper.Common;
using System.Net;

namespace SNSHelper.Kaixin001
{
    public class ParkingHelper : AppHelperBase
    {
        #region Properties
        private ParkerInfo parkerInfo;
        /// <summary>
        /// 玩家信息
        /// </summary>
        public ParkerInfo Parker
        {
            get
            {
                return parkerInfo;
            }
            set
            {
                parkerInfo = value;
            }
        }

        private List<CarInfo> carInfoList;
        /// <summary>
        /// 玩家车辆停车情况
        /// </summary>
        public List<CarInfo> CarList
        {
            get
            {
                return carInfoList;
            }
            set
            {
                carInfoList = value;
            }
        }

        private List<ParkingInfo> parkingInfoList;
        /// <summary>
        /// 玩家私家车位停车情况
        /// </summary>
        public List<ParkingInfo> ParkingList
        {
            get
            {
                return parkingInfoList;
            }
            set
            {
                parkingInfoList = value;
            }
        }

        private List<ParkerFriendInfo> parkerFriendInfoList;
        /// <summary>
        /// 玩家好友信息
        /// </summary>
        public List<ParkerFriendInfo> ParkerFriendList
        {
            get
            {
                return parkerFriendInfoList;
            }
            set
            {
                parkerFriendInfoList = value;
            }
        }

        private string verify;
        #endregion

        #region Constructor
        public ParkingHelper()
        {
            AppID = "1040";
            parkerInfo = new ParkerInfo();
            carInfoList = new List<CarInfo>();
            parkingInfoList = new List<ParkingInfo>();
            parkerFriendInfoList = new List<ParkerFriendInfo>();
            verify = string.Empty;
        }
        #endregion

        #region Public Method
        /// <summary>
        /// 获取泊车者相关信息：泊车者信息、自家车位停车情况、自己车辆的停车情况
        /// </summary>
        public void GetParkerDetails()
        {
            if (!Utility.IsLogin)
            {
                throw new Exception("请先登录!");
            }

            string parkingHTML = new HttpHelper().GetHtml(AppUrl + AppID, Utility.Cookies);  // AppUrl = "http://www.kaixin001.com/app/app.php?aid="; AppID = "1040";
            if (!parkingHTML.Contains("争车位"))
            {
                throw new Exception("读取争车位信息出错");
            }

            string userData = Utility.GetMidString(parkingHTML, "v_userdata = ", "\n");

            if (string.IsNullOrEmpty(userData))
	        {
                throw new Exception("读取争车位信息出错");
	        }

            userData = userData.Trim().Replace("\\/", "/").Replace("\\u", "\\\\u");

            object o = Newtonsoft.Json.JavaScriptConvert.DeserializeObject(userData);
            Newtonsoft.Json.JavaScriptObject jo = o as Newtonsoft.Json.JavaScriptObject;

            parkerInfo = new SNSHelper.Kaixin001.Entity.ParkerInfo(jo["user"]);
            string str = parkerInfo.RealName;

            Newtonsoft.Json.JavaScriptArray jsa = jo["parking"] as Newtonsoft.Json.JavaScriptArray;
            for (int i = 0; i < jsa.Count; i++)
            {
                parkingInfoList.Add(new SNSHelper.Kaixin001.Entity.ParkingInfo(jsa[i]));
            }

            jsa = jo["car"] as Newtonsoft.Json.JavaScriptArray;
            for (int i = 0; i < jsa.Count; i++)
            {
                carInfoList.Add(new SNSHelper.Kaixin001.Entity.CarInfo(jsa[i]));
            }

            string friendData = Utility.GetMidString(parkingHTML, "var v_frienddata = ", "\n"); // 获取v_frienddata变量
            friendData = friendData.Trim().Replace("\\/", "/").Replace("\\u", "\\\\u");
            o = Newtonsoft.Json.JavaScriptConvert.DeserializeObject(friendData);
            Newtonsoft.Json.JavaScriptArray jsaFriend = o as Newtonsoft.Json.JavaScriptArray;
            for (int i = 0; i < jsaFriend.Count; i++)
            {
                parkerFriendInfoList.Add(new SNSHelper.Kaixin001.Entity.ParkerFriendInfo(jsaFriend[i]));
            }

            verify = Utility.GetMidString(parkingHTML, "var g_verify = \"", "\";"); // 获取verify变量
        }

        /// <summary>
        /// 获取好友私家车位停车情况
        /// </summary>
        /// <param name="friendUId">好友编号</param>
        /// <returns></returns>
        public List<ParkingInfo> GetFirendParkingInfo(string friendUId)
        {
            string url = "http://www.kaixin001.com/parking/user.php";
            string postParams = string.Format("puid={0}&verify={1}&_=", friendUId, verify);

            string friendParkingJSON = new HttpHelper().GetHtml(url, postParams, true, Utility.Cookies);

            if (string.IsNullOrEmpty(friendParkingJSON))
            {
                return null;
            }

            friendParkingJSON = friendParkingJSON.Replace("\\/", "/").Replace("\\u", "\\\\u");

            List<ParkingInfo> friendParkingInfoList = new List<ParkingInfo>();

            object o = Newtonsoft.Json.JavaScriptConvert.DeserializeObject(friendParkingJSON);
            Newtonsoft.Json.JavaScriptObject jo = o as Newtonsoft.Json.JavaScriptObject;
            Newtonsoft.Json.JavaScriptArray jsa = jo["parking"] as Newtonsoft.Json.JavaScriptArray;
            for (int i = 0; i < jsa.Count; i++)
            {
                friendParkingInfoList.Add(new SNSHelper.Kaixin001.Entity.ParkingInfo(jsa[i]));
            }

            return friendParkingInfoList;
        }
        #endregion
    }
}
